import seaborn as sns
import pandas as pd
import matplotlib.pyplot as plt
import textwrap

from matplotlib.ticker import EngFormatter
from matplotlib.ticker import MultipleLocator

def plotTransmissionTimes(board, direction, column):
	fig = plt.figure(figsize=(6, 5))

	li = []
	li.append(pd.read_csv(board+"_ida_noTCP_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_noTCP_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_noTCP_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_noTCP_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_withTCP_wnd12_blk1M_cache_2kHz_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_withTCP_wnd12_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_withTCP_wnd8_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_withTCP_wnd4_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd12_blk1M_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd12_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd4_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd4_blk512k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk256k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk256k_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))

	frame = pd.concat(li, axis=1, ignore_index=True)
	frame = frame.div(1000000000)
	frame.columns = ['IDA noTCP','IDA noTCP noLoad', 'classic noTCP','classic noTCP noLoad', 'ida tcp 1M WND12 cache 2kHz','ida tcp 1M WND12', 'ida tcp 1M WND8','ida tcp 1M WND4','classic tcp 1M WND12 noLoad','classic tcp 1M WND12','classic tcp 1M WND8','classic tcp 1M WND4','classic tcp 512k WND4','classic tcp 256k WND8','classic tcp 256k WND8 noLoad']
	#frame.columns = ['IDA noTCP','IDA noTCP noLoad', 'ida tcp 1M WND12 2kHz','ida tcp 1M WND12', 'ida tcp 1M WND8','ida tcp 1M WND4']
	
	
	ax = sns.boxplot(data=frame, orient="h", linewidth=1.0, fliersize=2, medianprops={'color':'red', 'linewidth':'2'})
	ax.set_xlabel("80kB sample transmission delay")
	formatter0 = EngFormatter(unit='s',sep="")
	ax.xaxis.set_major_formatter(formatter0)
	#ax.xaxis.set_major_locator(MultipleLocator(0.00004))
	
		
	#tmp, x = ax.get_xlim()
	#for y, p, cMean in zip(ax.get_yticks(), frame2.iloc[0], classicMean):
		#ax.annotate('{:.0f}'.format(p),xy=(x, y),xytext=(0, 0),textcoords="offset points",ha='left', va='center')
                            
	#ax.annotate("Missing Samples", xy=(1,0.5), xycoords="axes fraction", xytext=(25,0), textcoords="offset points",ha="center", va="center",  rotation=-90)
	
	sns.despine(left=True)
	plt.savefig(board+"_"+direction+".pdf", bbox_inches = "tight")
	plt.clf()

def plotTransmissionTimesClassic(board, direction, column):
	fig = plt.figure(figsize=(6, 2))

	li = []
	li.append(pd.read_csv(board+"_classic_noTCP_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd12_blk1M_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_noTCP_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk256k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd4_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTCP_wnd12_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	
	
	
	#li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk256k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk256k_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	
	frame = pd.concat(li, axis=1, ignore_index=True)
	frame = frame.div(1000000000)
	frame.columns = ['noTCP noLoad', '1MB TCP, WND12 noLoad', 'noTCP','1M TCP, WND4','1MB TCP, WND8','1MB TCP, WND12']
	labels = ['noTCP', 'TCP, WND12', 'noTCP','TCP, WND4','TCP, WND8','TCP, WND12']
	
	ax = sns.boxplot(data=frame, orient="h", linewidth=1.0, fliersize=2, medianprops={'color':'red', 'linewidth':'2'})
	ax.set_xlabel("Latency of critical object transmission")
	formatter0 = EngFormatter(unit='s',sep="")
	ax.xaxis.set_major_formatter(formatter0)
	ax.set_yticklabels(labels)
	#ax.xaxis.set_major_locator(MultipleLocator(0.00004))
	
	ax.axhline(1.5, ls='--')
	ax.text(0.55,0.8, "No interf. appl. load",transform = ax.transAxes)
	ax.text(0.55,0.5, "35% interf. appl. load",transform = ax.transAxes)
	
	#tmp, x = ax.get_xlim()
	#for y, p, cMean in zip(ax.get_yticks(), frame2.iloc[0], classicMean):
	#	ax.annotate('{:.0f}'.format(p),xy=(x, y),xytext=(0, 0),textcoords="offset points",ha='left', va='center')
                            
	#ax.annotate("Missing Samples", xy=(1,0.5), xycoords="axes fraction", xytext=(25,0), textcoords="offset points",ha="center", va="center",  rotation=-90)
	
	sns.despine(left=True)
	plt.savefig(board+"_"+direction+"_classic.pdf", bbox_inches = "tight")
	plt.clf()
	
def plotTransmissionTimesIDA(board, direction, column):
	fig = plt.figure(figsize=(6, 2))

	li = []
	li.append(pd.read_csv(board+"_ida_noTCP_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_classic_withTCP_wnd12_blk1M_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_noTCP_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk256k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_withTCP_wnd4_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_withTCP_wnd8_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_ida_withTCP_wnd12_blk1M_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_ida_withTCP_wnd12_blk1M_cache_2kHz_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	
	
	#li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk256k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_classic_withTCP_wnd8_blk256k_noLoad_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	
	frame = pd.concat(li, axis=1, ignore_index=True)
	frame = frame.div(1000000000)
	frame.columns = ['noTCP noLoad', 'noTCP','1M TCP, WND4','1MB TCP, WND8','1MB TCP, WND12']
	labels = ['noTCP', 'noTCP','TCP, WND4','TCP, WND8','TCP, WND12']
	
	ax = sns.boxplot(data=frame, orient="h", linewidth=1.0, fliersize=2, medianprops={'color':'red', 'linewidth':'2'})
	ax.set_xlabel("Latency of critical object transmission")
	formatter0 = EngFormatter(unit='s',sep="")
	ax.xaxis.set_major_formatter(formatter0)
	ax.set_yticklabels([textwrap.fill(label, 12) for label in labels])
	ax.xaxis.set_major_locator(MultipleLocator(0.00004))
	
	ax.axhline(0.5, ls='--')
	ax.text(0.55,0.85, "No interf. appl. load",transform = ax.transAxes)
	ax.text(0.55,0.65, "35% interf. appl. load",transform = ax.transAxes)
	
	#tmp, x = ax.get_xlim()
	#for y, p, cMean in zip(ax.get_yticks(), frame2.iloc[0], classicMean):
	#	ax.annotate('{:.0f}'.format(p),xy=(x, y),xytext=(0, 0),textcoords="offset points",ha='left', va='center')
                            
	#ax.annotate("Missing Samples", xy=(1,0.5), xycoords="axes fraction", xytext=(25,0), textcoords="offset points",ha="center", va="center",  rotation=-90)
	
	sns.despine(left=True)
	plt.savefig(board+"_"+direction+"_ida.pdf", bbox_inches = "tight")
	plt.clf()

def plotTransmissionTimesWnd4Classic(board, direction, column):
	fig = plt.figure(figsize=(6, 2))

	li = []
	li.append(pd.read_csv(board+"_classic_noTcp_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk8k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk32k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk64k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk64k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	li.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk128k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_classic_withTcp_wnd16_blk64k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	#li.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk512k_"+direction+".csv", header=None, delimiter=";",usecols=[column]))
	limissing = []
	limissing.append(pd.read_csv(board+"_classic_noTcp_"+direction+"_missing.csv", header=None, delimiter=";",usecols=[0]))
	limissing.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk8k_"+direction+"_missing.csv", header=None, delimiter=";",usecols=[0]))
	limissing.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk32k_"+direction+"_missing.csv", header=None, delimiter=";",usecols=[0]))
	#limissing.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk64k_"+direction+"_missing.csv", header=None, delimiter=";",usecols=[0]))
	limissing.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk64k_"+direction+"_missing.csv", header=None, delimiter=";",usecols=[0]))
	limissing.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk128k_"+direction+"_missing.csv", header=None, delimiter=";",usecols=[0]))
	#limissing.append(pd.read_csv(board+"_classic_withTcp_wnd16_blk64k_"+direction+"_missing.csv", header=None, delimiter=";",usecols=[0]))
	#limissing.append(pd.read_csv(board+"_classic_withTcp_wnd4_blk512k_"+direction+"_missing.csv", header=None, delimiter=";",usecols=[0]))
	
	frame = pd.concat(li, axis=1, ignore_index=True)
	frame = frame.div(1000000000)
	frame.columns = ['no TCP', 'send(8k)', 'send(32k)', 'send(64k)', 'send(128k)']
	
	frame2 = pd.concat(limissing, axis=1, ignore_index=True)
	frame2.columns = frame.columns

	ax = sns.boxplot(data=frame, orient="h", linewidth=1.0, fliersize=2, medianprops={'color':'red', 'linewidth':'2'})
	
	ax.set_xlabel("80kB sample transmission delay")
	formatter0 = EngFormatter(unit='s',sep="")
	ax.xaxis.set_major_formatter(formatter0)
	
	tmp, x = ax.get_xlim()
	for y, p in zip(ax.get_yticks(), frame2.iloc[0]):
		ax.annotate('{:.0f}'.format(p), xy=(x, y), xytext=(0, 0), textcoords="offset points", ha='left', va='center')
                            
	ax.annotate("Missing Samples", xy=(1,0.5), xycoords="axes fraction", xytext=(27,0), textcoords="offset points",ha="center", va="center",  rotation=-90)

	
	sns.despine(left=True)
	plt.savefig(board+"_"+direction+"_classic.pdf", bbox_inches = "tight")
	plt.clf()
	
	
def plotThroughput():
	fig = plt.figure(figsize=(8, 2))
	ax = fig.add_subplot()

	#col_list = ["Classic send(512k) UDP", "Classic send(512k) TCP" ,"Filter send(512k) TCP"]
	
	frame = pd.read_csv("throughput.csv", delimiter=";", decimal=',');#,usecols=[0,2,3,5,6,7]);
	#frame.columns = ['Critical Traffic (UDP)','Classic background (TCP)',  'Improved background (TCP)']
	frame = frame.div(1000000)
	meanFrame = frame.mean()
	print(meanFrame)
	sns_plot = sns.lineplot(data=frame.rolling(5).mean(), legend="brief")
		 
	sns_plot.set_xlabel("Time")
	formatter0 = EngFormatter(unit='s')
	sns_plot.xaxis.set_major_formatter(formatter0)
	sns_plot.set(xlim=(10, 30))
	
	sns_plot.set_ylabel("Throuhput MBit/s")

	sns_plot.legend(loc='lower right', frameon=True)
	
	sns.despine(left=True)
	plt.savefig("throughput.pdf", bbox_inches = "tight")
	plt.clf()


sns.set(style="darkgrid", palette="muted", font_scale=1)

#plotThroughput()
#
#plotTransmissionTimesWnd4Classic("board2","rx",80)
#plotTransmissionTimesWnd4Classic("board1","rx",10)

#plotTransmissionTimesWnd4Classic("board2","tx",10)
#plotTransmissionTimesWnd4Classic("board1","tx",80)

#plotTransmissionTimesWnd4Ida("board2","rx",80)
#plotTransmissionTimesWnd4Ida("board1","rx",10)

#plotTransmissionTimesWnd4Ida("board2","tx",10)
#plotTransmissionTimesWnd4Ida("board1","tx",80)

plotThroughput()

plotTransmissionTimesClassic("board2","rx",80)
plotTransmissionTimesClassic("board1","rx",10)

plotTransmissionTimesIDA("board2","rx",80)
plotTransmissionTimesIDA("board1","rx",10)

plotTransmissionTimes("board2","rx",80)
plotTransmissionTimes("board1","rx",10)
